<?php
namespace api\modules\df\base;
use Yii;

class Model extends \yii\base\Model
{
    // Base model functionality can be defined here
    // This class can be extended by other models in the df module

    public function getDb(){
        return Yii::$app->get('df'); // Assuming 'df' is the database component for this module
    }
    
}